@@ -26,14 +26,14 @@ class RestoreSecretRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Kms', '2016-01-20', 'RestoreSecret','kms')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SecretName(self):
+	def get_SecretName(self): # String
 		return self.get_query_params().get('SecretName')
 
-	def set_SecretName(self,SecretName):
-		self.add_query_param('SecretName',SecretName)
\ No newline at end of file
+	def set_SecretName(self, SecretName):  # String
+		self.add_query_param('SecretName', SecretName)
